summaryrefslogtreecommitdiff
path: root/gtk/gtkclist.h
diff options
context:
space:
mode:
authorTim Janik <timj@gtk.org>1998-10-01 13:24:42 +0000
committerTim Janik <timj@src.gnome.org>1998-10-01 13:24:42 +0000
commitb89ed0c35f513007c26323b43c355b7f32a8f0ee (patch)
treec2c4f70af6ca8ea0ebea56894123aab3a5c66117 /gtk/gtkclist.h
parentfa5c68f7c677e76d42a1f8d26aefd95c68c729e3 (diff)
downloadgtk+-b89ed0c35f513007c26323b43c355b7f32a8f0ee.tar.gz
new function. (gtk_clist_insert): added g_return_val_if_fail() statements.
Thu Oct 1 10:40:20 1998 Tim Janik <timj@gtk.org> * gtk/gtkclist.h (gtk_clist_prepend): * gtk/gtkclist.c (gtk_clist_prepend): new function. (gtk_clist_insert): added g_return_val_if_fail() statements. accept a row parameter < 0 or > clist->rows to indicate append mode. (real_clear): first clean up all internal pointers and lists (e.g. clist->row_list or clist->rows), then delete the distinct rows. this is required because of destroy notifiers, we need to have all internal structures updated and be reentrant. * gtk/gtkcalendar.h: * gtk/gtkcalendar.c: removed the `gtk_calendar_' prefix from the GtkCalendarClass signal methods. GtkType and macro fixups, put `void' into () prototypes, avoid C++ style comments, indentation fixes, fixed some g_return_if_fail() statements. (gtk_calendar_paint_header): (gtk_calendar_paint_day_names): (gtk_calendar_paint_week_numbers): (gtk_calendar_paint_main): made these static functions. (gtk_calendar_select_month): (gtk_calendar_select_day): (gtk_calendar_mark_day): (gtk_calendar_unmark_day): (gtk_calendar_get_date): signedness corrections, use guints rather than gints. (gtk_calendar_size_request): removed unused variables.
Diffstat (limited to 'gtk/gtkclist.h')
-rw-r--r--gtk/gtkclist.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/gtk/gtkclist.h b/gtk/gtkclist.h
index 1e482bcf47..a8d2608f44 100644
--- a/gtk/gtkclist.h
+++ b/gtk/gtkclist.h
@@ -526,11 +526,13 @@ void gtk_clist_set_selectable (GtkCList *clist,
gboolean gtk_clist_get_selectable (GtkCList *clist,
gint row);
/* append returns the index of the row you just added, making
* it easier to append and modify a row
*/
-gint gtk_clist_append (GtkCList *clist,
- gchar *text[]);
+gint gtk_clist_prepend (GtkCList *clist,
+ gchar *text[]);
+gint gtk_clist_append (GtkCList *clist,
+ gchar *text[]);
/* inserts a row at index row and returns the row where it was actually
* inserted (may be different from "row" in auto_sort mode)
@@ -526,11 +526,13 @@ void gtk_clist_set_selectable (GtkCList *clist,
gboolean gtk_clist_get_selectable (GtkCList *clist,
gint row);
-/* append returns the index of the row you just added, making
- * it easier to append and modify a row
+/* prepend/append returns the index of the row you just added,
+ * making it easier to append and modify a row
*/